@@ -29,11 +29,11 @@ from sqlalchemy.exc import (
     NoSuchModuleError,
 )
 from sqlalchemy_aio import ASYNCIO_STRATEGY
+from sqlalchemy_aio.asyncio import AsyncioEngine
 from sqlalchemy_aio.base import (
     AsyncConnection,
     AsyncResultProxy,
 )
-from sqlalchemy_aio.engine import AsyncioEngine
 
 #: Timeout for a query
 QueryTimeout = Union[int, float]
@@ -252,6 +252,10 @@ class DataBase:
         except (ArgumentError, ValueError, NoSuchModuleError):
             raise self._db_error(f'Invalid database DSN: "{self.dsn}"', fatal=True)
 
+        # XXX workaround https://github.com/RazerM/sqlalchemy_aio/pull/37
+        self._engine.hide_parameters = self._engine.sync_engine.hide_parameters
+        self._engine.url = self._engine.sync_engine.url
+
         self._setup_query_latency_tracking()
 
     async def __aenter__(self):
